@@ -2,14 +2,14 @@
 This packages implements tomography algorithms and utilities in
 python. It is made of several modules
 
-- siddon: is the core of the package, with a fast C/OpenMP
-  implementation of the Siddon algorithm :
+- siddon: The core of the package, with a fast C/OpenMP
+  implementation of the Siddon algorithm.
   See : http://adsabs.harvard.edu/abs/1985MedPh..12..252S
 
-- simu: implements some utilities to perform simulations
+- simu: Implements some utilities to perform simulations.
 
-- secchi: a module to load STEREO/SECCHI data with appropriate
-  metadata
+- solar: A module to load Solar physics data with appropriate
+  metadata.
 
 - phantom: To generate phantoms (Shepp-Logan, Modified Shepp Logan,
   and Yu Ye Wang phantoms).
@@ -19,7 +19,7 @@ python. It is made of several modules
 
 from siddon import *
 import simu
-import secchi
+import solar
 import phantom
 import models
 
@@ -31,3 +31,5 @@ except ImportError:
 if 'lo' in locals():
     from lo_wrapper import *
 
+
+version = "0.3.0"
